@@ -22,12 +22,24 @@ class CachedRequest:
     url: str = field(default=None)
 
     @classmethod
-    def from_request(cls, original_request: PreparedRequest):
+    def from_request(cls, original_request: PreparedRequest) -> 'CachedRequest':
         """Create a CachedRequest based on an original request object"""
         kwargs = {k: getattr(original_request, k, None) for k in fields_dict(cls).keys()}
         kwargs['cookies'] = getattr(original_request, '_cookies', None)
         return cls(**kwargs)
 
+    def prepare(self) -> PreparedRequest:
+        """Convert the CachedRequest back into a PreparedRequest"""
+        prepared_request = PreparedRequest()
+        prepared_request.prepare(
+            cookies=self.cookies,
+            data=self.body,
+            headers=self.headers,
+            method=self.method,
+            url=self.url,
+        )
+        return prepared_request
+
     @property
     def _cookies(self):
         """For compatibility with PreparedRequest, which has an attribute named '_cookies', and a
